#
# spec file for package zypper-docker
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define go_tool go
%define GO_BUILD_FLAGS ""

%define version_unconverted 2.0.0

Name:           zypper-docker
Version:        2.0.0
Release:        lp151.1.7
Summary:        Easy patch and update solution for Docker images
License:        Apache-2.0
Group:          Development/Languages/Other
Url:            https://github.com/SUSE/zypper-docker
Source0:        %{name}-%{version}.tar.xz
Source42:       zypper-docker-rpmlintrc
BuildRequires:  go >= 1.9
# Build fails with PIE enabled on ppc64le due to boo#1098017
%ifarch ppc64le
#!BuildIgnore: gcc-PIE
%endif
Requires:       libzypp > 9.34
BuildRequires:  libzypp > 9.34
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    %ix86

%description
The zypper-docker command line tool provides a quick way to patch and update
Docker images based either on SUSE Linux Enterprise or openSUSE.

zypper-docker mimics zypper command line syntax to ease its usage.

zypper-docker relies on zypper to perform the actual operations against Docker images.

%prep
%setup -q

%build
export GOPATH=$PWD/go
mkdir -p $GOPATH/src/github.com/SUSE

# Copy the vendor directory into the GOPATH.
cp -r $PWD/vendor/* $GOPATH/src
ln -s $PWD $GOPATH/src/github.com/SUSE/zypper-docker

%go_tool build %GO_BUILD_FLAGS

# build man pages
cd man
%go_tool run generate.go

%check
export GOPATH=$PWD/go
%go_tool test -v

%install
%{__mkdir_p} %{buildroot}%{_bindir}
%{__install} -m755 zypper-docker-%{version} %{buildroot}%{_bindir}/zypper-docker

# install manpages
install -d %{buildroot}%{_mandir}/man1
install -p -m 644 man/man1/*.1 %{buildroot}%{_mandir}/man1

%files
%defattr(-,root,root)
%doc README.md
%license LICENSE
%{_bindir}/zypper-docker
%{_mandir}/man1/zypper-docker-*.1.gz
%{_mandir}/man1/zypper-docker.1.gz

%changelog
* Tue Mar 26 2019 Miquel Sabaté <msabate@suse.com>
- Fix build error with PIE linker flags on ppc64le.
  See boo#1098017
* Wed Jun 13 2018 dcassany@suse.com
- Make use of %%license macro
* Wed Jun 13 2018 parlt@suse.com
- Release version 2.0.0 (bsc#1097442)
  - Features:
  * Allow inspection of stopped containers
    Using zypper-docker luc,lpc or pchkc on a stopped container is now possible.
  * Analyze container instead of base image by default
    Note: This is a backwards incompatible change. If the base image of a container
    needs to be analyzed, which was the former default a new --base flag can be used.
    e.g. zypper-docker pchkc --base <Container-ID>
  - Minor Improvements / Fixes:
  * Add short forms of commands to help section
    Fixes: bsc#1022052
  * Fix bug that caused images not to be removed properly in some cases
  * Fix bug that caused lpc command to log to stdout
  * Fix bug that caused force flag not to work with zypper-docker images
  * Fix zypper-docker ps command
  * Fix bug with zypper-docker up/patch --no-recommends
  * Fix update behavior when getting a zypper update
  - Other:
  * Update and use zypper exit codes
    Fixes: bsc#1018823
  * Support recent version of the docker API
* Tue Apr 11 2017 jmassaguerpla@suse.com
- remove the go_arches macro because we are using go1.7 which
  is available in all archs
* Thu Aug 11 2016 jmassaguerpla@suse.com
- enable gc-go for ppc64le
* Wed May  4 2016 jmassaguerpla@suse.com
- Release version 1.2.0 (bsc#978467).
* Wed Apr 27 2016 jmassaguerpla@suse.com
- add zypper-docker-rpmlintrc as source in spec file, otherwise
  build service checks fail
* Tue Apr 26 2016 jmassaguerpla@suse.com
- Features:
  * The list-patches command has gained the --severity flag.
- Minor Improvements:
  * The --help flag is now more specific on commands arguments.
  * The cache file is now safe from concurrent accesses.
  * Clean zypper's cache after patch or update.
  * Display error message when image does not exist.
  * Run all zypper commands as root.
- Other:
  * Migrated client from samalba/dockerclient to docker/engine-api.
* Fri Dec  4 2015 msabate@suse.com
- Release v1.1.2 (bsc#957967)
  - The patch and the update commands no longer pollute the resulting image
  - Parse the image name:tag with distribution's reference package
* Mon Nov 30 2015 fcastelli@suse.com
- Ensure libgo is statically linked when building on Power and Z (bnc#957175)
* Thu Nov 26 2015 fcastelli@suse.com
- Release v 1.1.1:
  - Fix the prefix of the logger
  - Increase timeout when spawning containers
  - Ignore certain exit codes produces by zypper when doing patch and update
* Fri Nov 20 2015 fcastelli@suse.com
- Exclude building on x86
* Wed Nov 11 2015 jmassaguerpla@suse.com
- Release into the containers module
  FATE#319426
  bsc#954642
* Fri Oct 30 2015 fcastelli@suse.com
- Update to release 1.1.0:
  - make it possible to add extra hosts at runtime
  - always run in non-interactive mode
  - take global options into consideration when invoking zypper
* Wed Oct 14 2015 fcastelli@suse.com
- Release version 1.0.0
